# ourskyai-sda-api
The basic flow for a new organization is as follows:
1. View the available satellite targets with the [satellite targets](#operation/v1GetSatelliteTargets) endpoint. Copy the id of the target you want to observe.
2. Create an organization target with the [organization target](#operation/v1CreateOrganizationTarget) endpoint. Use the id copied from above.
3. Create a webhook with the [webhook](#operation/v1CreateWebhookConfiguration) endpoint to receive TDMs automatically (preferred) or use the [tdms](#operation/v1GetTdms) endpoint to poll for TDMs.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.3.1905
- Package version: 1.3.1905
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ourskyai_sda_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ourskyai_sda_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import ourskyai_sda_api
from ourskyai_sda_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.prod.oursky.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = ourskyai_sda_api.Configuration(
    host = "https://api.prod.oursky.ai"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerToken
configuration = ourskyai_sda_api.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with ourskyai_sda_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ourskyai_sda_api.DefaultApi(api_client)
    v1_create_image_set_request = ourskyai_sda_api.V1CreateImageSetRequest() # V1CreateImageSetRequest | 

    try:
        api_response = api_instance.v1_create_image_set(v1_create_image_set_request)
        print("The response of DefaultApi->v1_create_image_set:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->v1_create_image_set: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.prod.oursky.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**v1_create_image_set**](docs/DefaultApi.md#v1_create_image_set) | **POST** /v1/image-set | 
*DefaultApi* | [**v1_create_image_set_image**](docs/DefaultApi.md#v1_create_image_set_image) | **POST** /v1/image-set-image | 
*DefaultApi* | [**v1_create_organization_target**](docs/DefaultApi.md#v1_create_organization_target) | **POST** /v1/organization-target | 
*DefaultApi* | [**v1_create_webhook_configuration**](docs/DefaultApi.md#v1_create_webhook_configuration) | **POST** /v1/communications/webhook | 
*DefaultApi* | [**v1_delete_organization_target**](docs/DefaultApi.md#v1_delete_organization_target) | **DELETE** /v1/organization-target | 
*DefaultApi* | [**v1_delete_webhook_configuration**](docs/DefaultApi.md#v1_delete_webhook_configuration) | **DELETE** /v1/communications/webhook | 
*DefaultApi* | [**v1_get_image_set**](docs/DefaultApi.md#v1_get_image_set) | **GET** /v1/image-set | 
*DefaultApi* | [**v1_get_image_set_image**](docs/DefaultApi.md#v1_get_image_set_image) | **GET** /v1/image-set-image | 
*DefaultApi* | [**v1_get_image_set_images**](docs/DefaultApi.md#v1_get_image_set_images) | **GET** /v1/image-set-images | 
*DefaultApi* | [**v1_get_image_sets**](docs/DefaultApi.md#v1_get_image_sets) | **GET** /v1/image-sets | 
*DefaultApi* | [**v1_get_observation_sequence_results**](docs/DefaultApi.md#v1_get_observation_sequence_results) | **GET** /v1/observation-sequence-results | 
*DefaultApi* | [**v1_get_organization_targets**](docs/DefaultApi.md#v1_get_organization_targets) | **GET** /v1/organization-targets | 
*DefaultApi* | [**v1_get_satellite_potentials**](docs/DefaultApi.md#v1_get_satellite_potentials) | **GET** /v1/satellite-target-potentials | 
*DefaultApi* | [**v1_get_satellite_targets**](docs/DefaultApi.md#v1_get_satellite_targets) | **GET** /v1/satellite-targets | 
*DefaultApi* | [**v1_get_tdm**](docs/DefaultApi.md#v1_get_tdm) | **GET** /v1/tdm | 
*DefaultApi* | [**v1_get_tdms**](docs/DefaultApi.md#v1_get_tdms) | **GET** /v1/tdms | 
*DefaultApi* | [**v1_get_webhook_configurations**](docs/DefaultApi.md#v1_get_webhook_configurations) | **GET** /v1/communications/webhooks | 
*DefaultApi* | [**v1_update_email_configuration**](docs/DefaultApi.md#v1_update_email_configuration) | **PUT** /v1/communications/email | 


## Documentation For Models

 - [AstrometricOffsets](docs/AstrometricOffsets.md)
 - [EmptySuccess](docs/EmptySuccess.md)
 - [FilterType](docs/FilterType.md)
 - [ObservationResult](docs/ObservationResult.md)
 - [OrbitType](docs/OrbitType.md)
 - [SuccessfulCreate](docs/SuccessfulCreate.md)
 - [TrackingType](docs/TrackingType.md)
 - [V1CreateImageSetImageRequest](docs/V1CreateImageSetImageRequest.md)
 - [V1CreateImageSetImageResponse](docs/V1CreateImageSetImageResponse.md)
 - [V1CreateImageSetRequest](docs/V1CreateImageSetRequest.md)
 - [V1CreateOrganizationTargetRequest](docs/V1CreateOrganizationTargetRequest.md)
 - [V1GetSatelliteTargetsResponse](docs/V1GetSatelliteTargetsResponse.md)
 - [V1ImageSet](docs/V1ImageSet.md)
 - [V1ImageSetImage](docs/V1ImageSetImage.md)
 - [V1ObservationSequenceResult](docs/V1ObservationSequenceResult.md)
 - [V1ObservationSequenceResultImageSetsInner](docs/V1ObservationSequenceResultImageSetsInner.md)
 - [V1OrganizationTarget](docs/V1OrganizationTarget.md)
 - [V1SatellitePotential](docs/V1SatellitePotential.md)
 - [V1SatelliteTarget](docs/V1SatelliteTarget.md)
 - [V1Tdm](docs/V1Tdm.md)
 - [V1UpdateEmailConfigurationRequest](docs/V1UpdateEmailConfigurationRequest.md)
 - [V1UpdateWebhookConfigurationRequest](docs/V1UpdateWebhookConfigurationRequest.md)
 - [V1WebhookConfiguration](docs/V1WebhookConfiguration.md)
 - [WebhookEvent](docs/WebhookEvent.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerToken"></a>
### BearerToken

- **Type**: Bearer authentication

<a id="Roles"></a>
### Roles



## Author




